@@ -1,3 +1,7 @@
+/* exported audioProfile displayTime list offsetController
+            play recordPipeline view volumeValue wave ActiveArea
+            RecordPipelineStates _SEC_TIMEOUT MainWindow
+            EncoderComboBox ChannelsComboBox */
 /*
 * Copyright 2013 Meg Ford
 * This library is free software; you can redistribute it and/or
@@ -23,9 +27,9 @@ const Gdk = imports.gi.Gdk;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Pango = imports.gi.Pango;
 
 const Application = imports.application;
@@ -33,35 +37,33 @@ const AudioProfile = imports.audioProfile;
 const FileUtil = imports.fileUtil;
 const Info = imports.info;
 const Listview = imports.listview;
-const Params = imports.params;
 const Play = imports.play;
 const Preferences = imports.preferences;
 const Record = imports.record;
 const Waveform = imports.waveform;
 
 let activeProfile = null;
-let audioProfile = null;
-let displayTime = null;
+var audioProfile = null;
+var displayTime = null;
 let grid = null;
 let groupGrid;
 let header;
-let list = null;
+var list = null;
 let loadMoreButton = null;
-let offsetController = null;
-let play = null;
+var offsetController = null;
+var play = null;
 let previousSelRow = null;
-let recordPipeline = null;
+var recordPipeline = null;
 let recordButton = null;
+let appMenuButton = null;
 let selectable = null;
 let setVisibleID = null;
 let UpperBoundVal = 182;
-let view = null;
-let volumeValue = [];
+var view = null;
+var volumeValue = [];
 var wave = null;
 
-const rtl = Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL;
-
-const ActiveArea = {
+var ActiveArea = {
     RECORD: 0,
     PLAY: 1
 };
@@ -77,33 +79,33 @@ const PipelineStates = {
     STOPPED: 2
 };
 
-const RecordPipelineStates = {
+var RecordPipelineStates = {
     PLAYING: 0,
     PAUSED: 1,
     STOPPED: 2
 };
 
 const _TIME_DIVISOR = 60;
-const _SEC_TIMEOUT = 100;
+var _SEC_TIMEOUT = 100;
 
-const MainWindow = new Lang.Class({
-    Name: 'MainWindow',
-    Extends: Gtk.ApplicationWindow,
-
-     _init: function(params) {
+var MainWindow = GObject.registerClass(class MainWindow extends Gtk.ApplicationWindow {
+     _init(params) {
         audioProfile = new AudioProfile.AudioProfile();
         offsetController = new FileUtil.OffsetController;
         displayTime = new FileUtil.DisplayTime;
         view = new MainView();
         play = new Play.Play();
 
-        params = Params.fill(params, { title: GLib.get_application_name(),
-                                       default_height: 480,
-                                       default_width: 780,
-                                       hexpand: true,
-                                       vexpand: true,
-                                       icon_name: "org.gnome.SoundRecorder" });
-        this.parent(params);
+        super._init(Object.assign({
+            title: GLib.get_application_name(),
+            default_height: 480,
+            default_width: 780,
+            height_request: 480,
+            width_request: 640,
+            hexpand: true,
+            vexpand: true,
+            icon_name: "org.gnome.SoundRecorder"
+        }, params));
 
         header = new Gtk.HeaderBar({ hexpand: true,
                                      show_close_button: true });
@@ -111,30 +113,42 @@ const MainWindow = new Lang.Class({
         header.get_style_context().add_class('titlebar');
 
         recordButton = new RecordButton({ label: _("Record") });
-        recordButton.get_style_context().add_class('destructive-action');
+        recordButton.get_style_context().add_class('suggested-action');
         header.pack_start(recordButton);
 
+        this._addAppMenu();
+
         this.add(view);
         this.show_all();
     }
+
+    _addAppMenu() {
+        let menu = new Gio.Menu();
+        menu.append(_("Preferences"), 'app.preferences');
+        menu.append(_("About Sound Recorder"), 'app.about');
+
+        appMenuButton = new Gtk.MenuButton({
+          image: new Gtk.Image({ icon_name: 'open-menu-symbolic' }),
+          menu_model: menu
+        });
+        header.pack_end(appMenuButton);
+    }
 });
 
-const MainView = new Lang.Class({
-    Name: 'MainView',
-    Extends: Gtk.Stack,
-
-    _init: function(params) {
-        params = Params.fill(params, { vexpand: true,
-                                       transition_type: Gtk.StackTransitionType.CROSSFADE,
-                                       transition_duration: 100,
-                                       visible: true });
-        this.parent(params);
+const MainView = GObject.registerClass(class MainView extends Gtk.Stack {
+    _init(params) {
+        super._init(Object.assign({
+            vexpand: true,
+            transition_type: Gtk.StackTransitionType.CROSSFADE,
+            transition_duration: 100,
+            visible: true
+        }, params));
 
         this._addListviewPage('listviewPage');
         this.labelID = null;
-    },
+    }
 
-    _addEmptyPage: function() {
+    _addEmptyPage() {
         this.emptyGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                         hexpand: true,
                                         vexpand: true,
@@ -159,9 +173,9 @@ const MainView = new Lang.Class({
         emptyPageDirections.get_style_context().add_class('dim-label');
         this.emptyGrid.add(emptyPageDirections);
         this.emptyGrid.show_all();
-    },
+    }
 
-    _addListviewPage: function(name) {
+    _addListviewPage(name) {
         list = new Listview.Listview();
         list.setListTypeNew();
         list.enumerateDirectory();
@@ -171,51 +185,48 @@ const MainView = new Lang.Class({
                                    hexpand: true,
                                    vexpand: true });
         this.add_titled(groupGrid, name, "View");
-    },
+    }
 
-    onPlayStopClicked: function() {
+    onPlayStopClicked() {
         if (play.getPipeStates() == PipelineStates.PLAYING) {
             play.stopPlaying();
             let listRow = this.listBox.get_selected_row();
-            let rowWidget = listRow.get_child(this.widget);
-            rowWidget.foreach(Lang.bind(this,
-                function(child) {
+            let rowGrid = listRow.get_child();
+            rowGrid.foreach((child) => {
+                if (child.name == "PauseButton") {
+                    child.hide();
+                    child.sensitive = false;
+                }
+                else if (child.name == "PlayLabelBox") {
+                    child.show();
+                    child.foreach((grandchild) => {
+                        if (grandchild.name == "PlayTimeLabel") {
+                            grandchild.hide();
+                        }
 
-                    if (child.name == "PauseButton") {
-                        child.hide();
-                        child.sensitive = false;
-                    }
-                    else if (child.name == "PlayLabelBox") {
-                        child.show();
-                        child.foreach(Lang.bind(this,
-                            function(grandchild) {
-
-                                if (grandchild.name == "PlayTimeLabel") {
-                                    grandchild.hide();
-                                }
-
-                                if (grandchild.name == "DividerLabel" )
-                                    grandchild.hide();
-                             }));
-                    }
-                    else {
-                        child.show();
-                        child.sensitive = true;
-                    }
-                }));
+                        if (grandchild.name == "DividerLabel") {
+                            grandchild.hide();
+                        }
+                    });
+                }
+                else {
+                    child.show();
+                    child.sensitive = true;
+                }
+            });
         }
-    },
+    }
 
-    onRecordStopClicked: function() {
+    onRecordStopClicked() {
         this._record.stopRecording();
         this.recordGrid.hide();
         recordPipeline = RecordPipelineStates.STOPPED;
         recordButton.set_sensitive(true);
         if (this.listBox != null)
             this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);
-    },
+    }
 
-    _formatTime: function(unformattedTime) {
+    _formatTime(unformattedTime) {
         this.unformattedTime = unformattedTime;
         let seconds = Math.floor(this.unformattedTime);
         let hours = parseInt(seconds / Math.pow(_TIME_DIVISOR, 2));
@@ -235,18 +246,18 @@ const MainView = new Lang.Class({
             (secondString < 10 ? "0" + secondString : secondString);
 
         return timeString;
-    },
+    }
 
-    _updatePositionCallback: function() {
+    _updatePositionCallback() {
         let position = MainWindow.play.queryPosition();
 
         if (position >= 0) {
             this.progressScale.set_value(position);
         }
         return true;
-    },
+    }
 
-    presetVolume: function(source, vol) {
+    presetVolume(source, vol) {
         if (source == ActiveArea.PLAY) {
             volumeValue[0].play = vol;
             Application.application.setSpeakerVolume(vol);
@@ -254,23 +265,23 @@ const MainView = new Lang.Class({
             volumeValue[0].record = vol;
             Application.application.setMicVolume(vol);
         }
-    },
+    }
 
-    setVolume: function() {
+    setVolume() {
         if (setVisibleID == ActiveArea.PLAY) {
             play.setVolume(volumeValue[0].play);
         } else if (setVisibleID == ActiveArea.RECORD) {
            this._record.setVolume(volumeValue[0].record);
         }
-    },
+    }
 
-    getVolume: function() {
+    getVolume() {
         let volumeValue = this.playVolume.get_value();
 
         return volumeValue;
-    },
+    }
 
-    listBoxAdd: function() {
+    listBoxAdd() {
         selectable = true;
         this.groupGrid = groupGrid;
         let playVolume = Application.application.getSpeakerVolume();
@@ -320,19 +331,17 @@ const MainView = new Lang.Class({
                                           margin_start: 6,
                                           margin_top: 6 });
         stopRecord.get_style_context().add_class('text-button');
-        stopRecord.connect("clicked", Lang.bind(this, this.onRecordStopClicked));
+        stopRecord.connect("clicked", () => this.onRecordStopClicked());
         this.toolbarStart.pack_start(stopRecord, true, true, 0);
         this.recordGrid.attach(this.toolbarStart, 5, 1, 2, 2);
-    },
+    }
 
-    scrolledWinAdd: function() {
-        this._scrolledWin = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN,
-                                                     vexpand: true });
+    scrolledWinAdd() {
+        this._scrolledWin = new Gtk.ScrolledWindow({ vexpand: true });
         this._scrolledWin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         this.scrollbar = this._scrolledWin.get_vadjustment();
 
-        this.scrollbar.connect("value_changed", Lang.bind(this,
-            function() {
+        this.scrollbar.connect("value_changed", () => {
                 this.currentBound = this.scrollbar.get_value();
                 UpperBoundVal = this.scrollbar.upper - this.scrollbar.page_size;
                 if (UpperBoundVal == this.currentBound && loadMoreButton == null) {
@@ -341,7 +350,7 @@ const MainView = new Lang.Class({
                     loadMoreButton.destroy();
                     loadMoreButton = null;
                 }
-            }));
+            });
 
         this.groupGrid.add(this._scrolledWin);
         this._scrolledWin.show();
@@ -353,7 +362,7 @@ const MainView = new Lang.Class({
                                      "%d Recorded Sounds",
                                       sounds).format(sounds);
         } else {
-            title = "";
+            title = _("No Recorded Sounds");
         }
         header.set_title(title);
 
@@ -370,10 +379,9 @@ const MainView = new Lang.Class({
             this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);
             this.listBox.set_header_func(null);
             this.listBox.set_activate_on_single_click(true);
-            this.listBox.connect("row-selected", Lang.bind(this,
-                function(){
-                    this.rowGridCallback()
-                }));
+            this.listBox.connect("row-selected", () => {
+                this.rowGridCallback()
+            });
             this.listBox.show();
 
             this._files = [];
@@ -391,46 +399,42 @@ const MainView = new Lang.Class({
 
                 // play button
                 this.playImage = new Gtk.Image({ name: "PlayImage" });
-                this.playImage.set_from_icon_name(rtl ? 'media-playback-start-rtl-symbolic' :
-                                                        'media-playback-start-symbolic',
-                                                  Gtk.IconSize.BUTTON);
+                this.playImage.set_from_icon_name('media-playback-start-symbolic', Gtk.IconSize.BUTTON);
                 this._playListButton = new Gtk.Button({ name: "PlayButton",
-                                                        hexpand: true,
+                                                        hexpand: false,
                                                         vexpand: true });
                 this._playListButton.set_image(this.playImage);
                 this._playListButton.set_tooltip_text(_("Play"));
                 this.rowGrid.attach(this._playListButton, 0, 0, 2, 2);
                 this._playListButton.show();
-                this._playListButton.connect('clicked', Lang.bind(this,
-                    function(button){
-                        let row = button.get_parent().get_parent();
-                        this.listBox.select_row(row);
-                        play.passSelected(row);
-                        let gridForName = row.get_child();
-                        let idx = parseInt(gridForName.name);
-                        let file = this._files[idx];
-                        this.onPlayPauseToggled(row, file);
-                    }));
+                this._playListButton.connect('clicked', (button) => {
+                    let row = button.get_parent().get_parent();
+                    this.listBox.select_row(row);
+                    play.passSelected(row);
+                    let gridForName = row.get_child();
+                    let idx = parseInt(gridForName.name);
+                    let file = this._files[idx];
+                    this.onPlayPauseToggled(row, file);
+                });
 
                 // pause button
                 this.pauseImage = Gtk.Image.new();
                 this.pauseImage.set_from_icon_name('media-playback-pause-symbolic', Gtk.IconSize.BUTTON);
                 this._pauseListButton = new Gtk.Button({ name: "PauseButton",
-                                                         hexpand: true,
+                                                         hexpand: false,
                                                          vexpand: true });
                 this._pauseListButton.set_image(this.pauseImage);
                 this._pauseListButton.set_tooltip_text(_("Pause"));
                 this.rowGrid.attach(this._pauseListButton, 0, 0, 2, 2);
                 this._pauseListButton.hide();
-                this._pauseListButton.connect('clicked', Lang.bind(this,
-                    function(button){
-                        let row = button.get_parent().get_parent();
-                        this.listBox.select_row(row);
-                        this.onPause(row);
-                    }));
+                this._pauseListButton.connect('clicked', (button) => {
+                    let row = button.get_parent().get_parent();
+                    this.listBox.select_row(row);
+                    this.onPause(row);
+                });
 
                 this._fileName = new Gtk.Label({ name: "FileNameLabel",
-                                                 ellipsize: rtl ? Pango.EllipsizeMode.START : Pango.EllipsizeMode.END,
+                                                 ellipsize: Pango.EllipsizeMode.END,
                                                  halign: Gtk.Align.START,
                                                  valign: Gtk.Align.START,
                                                  margin_start: 15,
@@ -503,15 +507,14 @@ const MainView = new Lang.Class({
                                               vexpand: true,
                                               margin_end: 2 });
                 this._info.image = Gtk.Image.new_from_icon_name("dialog-information-symbolic", Gtk.IconSize.BUTTON);
-                this._info.connect("clicked", Lang.bind(this,
-                    function(button) {
-                        let row = button.get_parent().get_parent();
-                        this.listBox.select_row(row);
-                        let gridForName = row.get_child();
-                        let idx = parseInt(gridForName.name);
-                        let file = this._files[idx];
-                        this._onInfoButton(file);
-                    }));
+                this._info.connect("clicked", (button) => {
+                    let row = button.get_parent().get_parent();
+                    this.listBox.select_row(row);
+                    let gridForName = row.get_child();
+                    let idx = parseInt(gridForName.name);
+                    let file = this._files[idx];
+                    this._onInfoButton(file);
+                });
                 this._info.set_tooltip_text(_("Info"));
                 this.rowGrid.attach(this._info, 27, 0, 1, 2);
                 this._info.hide();
@@ -521,35 +524,34 @@ const MainView = new Lang.Class({
                                                 hexpand: false,
                                                 margin_start: 2, });
                 this._delete.image = Gtk.Image.new_from_icon_name("user-trash-symbolic", Gtk.IconSize.BUTTON);
-                this._delete.connect("clicked", Lang.bind(this,
-                    function(button) {
-                        let row = button.get_parent().get_parent();
-                        this.listBox.select_row(row);
-                        this._deleteFile(row);
-                    }));
+                this._delete.connect("clicked", (button) => {
+                    let row = button.get_parent().get_parent();
+                    this.listBox.select_row(row);
+                    this._deleteFile(row);
+                });
                 this._delete.set_tooltip_text(_("Delete"));
                 this.rowGrid.attach(this._delete, 28, 0, 1, 2);
                 this._delete.hide();
             }
         }
         list.monitorListview();
-    },
+    }
 
-    addLoadMoreButton: function() {
+    addLoadMoreButton() {
        loadMoreButton = new LoadMoreButton();
-       loadMoreButton.connect('clicked', Lang.bind(this, loadMoreButton.onLoadMore));
+       loadMoreButton.connect('clicked', () => loadMoreButton.onLoadMore());
        this.groupGrid.add(loadMoreButton);
        loadMoreButton.show();
-    },
+    }
 
-    destroyLoadMoreButton: function() {
+    destroyLoadMoreButton() {
         if (loadMoreButton != null) {
             loadMoreButton.destroy();
             loadMoreButton = null;
         }
-    },
+    }
 
-    listBoxRefresh: function() {
+    listBoxRefresh() {
         this.destroyLoadMoreButton();
         previousSelRow = null;
 
@@ -559,132 +561,125 @@ const MainView = new Lang.Class({
 
         list.setListTypeRefresh();
         list.enumerateDirectory();
-    },
+    }
 
-    listBoxLoadMore: function() {
+    listBoxLoadMore() {
        this.destroyLoadMoreButton();
        previousSelRow = null;
        this.listBox.set_selection_mode(Gtk.SelectionMode.NONE);
        offsetController.increaseEndIdxStep();
        list.setListTypeRefresh();
        list._setDiscover();
-    },
+    }
 
-    scrolledWinDelete: function() {
+    scrolledWinDelete() {
         this._scrolledWin.destroy();
         this.scrolledWinAdd();
-    },
+    }
 
-    hasPreviousSelRow: function() {
-       this.destroyLoadMoreButton();
-           if (previousSelRow != null) {
-              let rowWidget = previousSelRow.get_child(this.widget);
-              rowWidget.foreach(Lang.bind(this,
-                function(child) {
-                    let alwaysShow = child.get_no_show_all();
+    hasPreviousSelRow() {
+        this.destroyLoadMoreButton();
+        if (previousSelRow != null) {
+            let rowGrid = previousSelRow.get_child();
+            rowGrid.foreach((child) => {
+                let alwaysShow = child.get_no_show_all();
 
-                    if (!alwaysShow)
-                        child.hide();
+                if (!alwaysShow)
+                    child.hide();
 
-                    if (child.name == "PauseButton") {
-                        child.hide();
-                        child.sensitive = false;
-                    }
-                    if (child.name == "PlayButton") {
-                        child.show();
-                        child.sensitive = true;
-                    }
-
-                    if (child.name == "PlayLabelBox") {
-                        child.show();
-                        child.foreach(Lang.bind(this,
-                            function(grandchild) {
-
-                                if (grandchild.name == "PlayTimeLabel") {
-                                    grandchild.hide();
-                                }
-
-                                if (grandchild.name == "DividerLabel" )
-                                    grandchild.hide();
-                             }));
-                    }
-                }));
-
-                if (play.getPipeStates() == PipelineStates.PLAYING || play.getPipeStates()== PipelineStates.PAUSED) {
-                    play.stopPlaying();
+                if (child.name == "PauseButton") {
+                    child.hide();
+                    child.sensitive = false;
+                }
+                if (child.name == "PlayButton") {
+                    child.show();
+                    child.sensitive = true;
                 }
-            }
-        previousSelRow = null;
-    },
 
-    rowGridCallback: function() {
+                if (child.name == "PlayLabelBox") {
+                    child.show();
+                    child.foreach((grandchild) => {
+                        if (grandchild.name == "PlayTimeLabel") {
+                            grandchild.hide();
+                        }
+
+                        if (grandchild.name == "DividerLabel") {
+                            grandchild.hide();
+                        }
+                    });
+                }
+            });
+
+            if (play.getPipeStates() == PipelineStates.PLAYING || play.getPipeStates()== PipelineStates.PAUSED) {
+                play.stopPlaying();
+            }
+        }
+        previousSelRow = null;
+    }
+
+    rowGridCallback() {
         let selectedRow = this.listBox.get_selected_row();
         this.destroyLoadMoreButton();
 
         if (selectedRow) {
-
             if (previousSelRow != null) {
                 this.hasPreviousSelRow();
             }
 
             previousSelRow = selectedRow;
-            let selectedRowWidget = previousSelRow.get_child(this.widget);
-            selectedRowWidget.show_all();
-            selectedRowWidget.foreach(Lang.bind(this,
-                function(child) {
-                    let alwaysShow = child.get_no_show_all();
+            let selectedRowGrid = previousSelRow.get_child();
+            selectedRowGrid.show_all();
+            selectedRowGrid.foreach((child) => {
+                let alwaysShow = child.get_no_show_all();
 
-                    if (!alwaysShow)
-                        child.sensitive = true;
+                if (!alwaysShow)
+                    child.sensitive = true;
 
-                    if (child.name == "PauseButton") {
-                        child.hide();
-                        child.sensitive = false;
-                    }
-
-                    if (child.name == "WaveFormGrid")
-                        child.sensitive = true;
-                }));
-        }
-    },
-
-    _getFileFromRow: function(selected) {
-        let fileForAction = null;
-        let rowWidget = selected.get_child(this.fileName);
-        rowWidget.foreach(Lang.bind(this,
-            function(child) {
-
-                if (child.name == "FileNameLabel") {
-                    let name = child.get_text();
-                    let application = Gio.Application.get_default();
-                    fileForAction = application.saveDir.get_child_for_display_name(name);
+                if (child.name == "PauseButton") {
+                    child.hide();
+                    child.sensitive = false;
                 }
-             }));
+
+                if (child.name == "WaveFormGrid")
+                    child.sensitive = true;
+            });
+        }
+    }
+
+    _getFileFromRow(selected) {
+        let fileForAction = null;
+        let rowGrid = selected.get_child();
+        rowGrid.foreach((child) => {
+            if (child.name == "FileNameLabel") {
+                let name = child.get_text();
+                let application = Gio.Application.get_default();
+                fileForAction = application.saveDir.get_child_for_display_name(name);
+            }
+        });
 
         return fileForAction;
-    },
+    }
 
-    _deleteFile: function(selected) {
+    _deleteFile(selected) {
         let fileToDelete = this._getFileFromRow(selected);
         fileToDelete.trash_async(GLib.PRIORITY_DEFAULT, null, null);
-    },
+    }
 
-    loadPlay: function(selected) {
+    loadPlay(selected) {
         let fileToPlay = this._getFileFromRow(selected);
 
         return fileToPlay;
-    },
+    }
 
-    _onInfoButton: function(selected) {
+    _onInfoButton(selected) {
         let infoDialog = new Info.InfoDialog(selected);
 
-        infoDialog.widget.connect('response', Lang.bind(this,
-            function(widget, response) {
-                infoDialog.widget.destroy();
-            }));
-    },
+        infoDialog.widget.connect('response', (widget, response) => {
+            infoDialog.widget.destroy();
+        });
+    }
 
-    setLabel: function(time) {
+    setLabel(time) {
         this.time = time
 
         this.timeLabelString = this._formatTime(time);
@@ -695,85 +690,81 @@ const MainView = new Lang.Class({
         } else if (setVisibleID == ActiveArea.PLAY) {
             this.playTimeLabel.label = this.timeLabelString;
         }
-    },
+    }
+
+    setNameLabel(newName, oldName, index) {
 
-    setNameLabel: function(newName, oldName, index) {
         let selected = this.listBox.get_row_at_index(index);
-        let rowWidget = selected.get_child(oldName);
-        rowWidget.foreach(Lang.bind(this,
-            function(child) {
+        let rowGrid = selected.get_child();
+        rowGrid.foreach((child) => {
+            if (child.name == "FileNameLabel") {
+                let name = child.get_text();
+                let markup = ('<b>'+ newName + '</b>');
+                child.label = markup;
+            }
+        });
+        rowGrid.set_name(newName);
+    }
 
-                if (child.name == "FileNameLabel") {
-                    let name = child.get_text();
-                    let markup = ('<b>'+ newName + '</b>');
-                    child.label = markup;
-                }
-             }));
-        rowWidget.set_name(newName);
-    },
-
-    onPause: function(listRow) {
+    onPause(listRow) {
         let activeState = play.getPipeStates();
 
         if (activeState == PipelineStates.PLAYING) {
             play.pausePlaying();
-            let rowWidget = listRow.get_child(this.widget);
-            rowWidget.foreach(Lang.bind(this,
-                function(child) {
 
-                    if (child.name == "PauseButton") {
-                        child.hide();
-                        child.sensitive = false;
-                    }
+            let rowGrid = listRow.get_child();
+            rowGrid.foreach((child) => {
+                if (child.name == "PauseButton") {
+                    child.hide();
+                    child.sensitive = false;
+                }
 
-                    if (child.name == "PlayButton" ) {
-                        child.show();
-                        child.sensitive = true;
-                    }
-                }));
+                if (child.name == "PlayButton") {
+                    child.show();
+                    child.sensitive = true;
+                }
+            });
         }
-    },
+    }
 
-    onPlayPauseToggled: function(listRow, selFile) {
+    onPlayPauseToggled(listRow, selFile) {
         setVisibleID = ActiveArea.PLAY;
         let activeState = play.getPipeStates();
 
         if (activeState != PipelineStates.PLAYING) {
             play.startPlaying();
 
-            let rowWidget = listRow.get_child(this.widget);
-            rowWidget.foreach(Lang.bind(this,
-                function(child) {
 
-                    if (child.name == "InfoButton" || child.name == "DeleteButton" ||
-                        child.name == "PlayButton" ) {
-                        child.hide();
-                        child.sensitive = false;
-                    }
+            let rowGrid = listRow.get_child();
+            rowGrid.foreach((child) => {
+                if (child.name == "InfoButton" || child.name == "DeleteButton" ||
+                    child.name == "PlayButton") {
+                    child.hide();
+                    child.sensitive = false;
+                }
 
-                    if (child.name == "PauseButton") {
-                        child.show();
-                        child.sensitive = true;
-                    }
+                if (child.name == "PauseButton") {
+                    child.show();
+                    child.sensitive = true;
+                }
 
-                    if (child.name == "PlayLabelBox") {
-                        child.foreach(Lang.bind(this,
-                            function(grandchild) {
+                if (child.name == "PlayLabelBox") {
+                    child.foreach((grandchild) => {
+                        if (grandchild.name == "PlayTimeLabel") {
+                            view.playTimeLabel = grandchild;
+                        }
 
-                                if (grandchild.name == "PlayTimeLabel") {
-                                    view.playTimeLabel = grandchild;
-                                }
+                        if (grandchild.name == "DividerLabel") {
+                            grandchild.show();
+                        }
+                    });
+                }
 
-                                if (grandchild.name == "DividerLabel" )
-                                    grandchild.show();
-                             }));
-                    }
-
-                    if (child.name == "WaveFormGrid") {
-                        this.wFGrid = child;
-                        child.sensitive = true;
-                    }
-                }));
+                if (child.name == "WaveFormGrid") {
+                    this.wFGrid = child;
+                    child.sensitive = true;
+                }
+            });
 
             if (activeState != PipelineStates.PAUSED) {
                 wave = new Waveform.WaveForm(this.wFGrid, selFile);
@@ -782,21 +773,18 @@ const MainView = new Lang.Class({
     }
 });
 
-const RecordButton = new Lang.Class({
-    Name: "RecordButton",
-    Extends: Gtk.Button,
-
-    _init: function(activeProfile) {
-        this.parent();
+const RecordButton = GObject.registerClass(class RecordButton extends Gtk.Button {
+    _init(activeProfile) {
+        super._init();
         this.image = Gtk.Image.new_from_icon_name('media-record-symbolic', Gtk.IconSize.BUTTON);
         this.set_always_show_image(true);
         this.set_valign(Gtk.Align.CENTER);
         this.set_label(_("Record"));
         this.get_style_context().add_class('text-button');
-        this.connect("clicked", Lang.bind(this, this._onRecord));
-    },
+        this.connect("clicked", () => this._onRecord());
+    }
 
-    _onRecord: function() {
+    _onRecord() {
         view.destroyLoadMoreButton();
         view.hasPreviousSelRow();
 
@@ -819,13 +807,10 @@ const RecordButton = new Lang.Class({
     }
 });
 
-const EncoderComboBox = new Lang.Class({
-    Name: "EncoderComboBox",
-    Extends: Gtk.ComboBoxText,
-
+var EncoderComboBox = GObject.registerClass(class EncoderComboBox extends Gtk.ComboBoxText {
     // encoding setting labels in combobox
-    _init: function() {
-        this.parent();
+    _init() {
+        super._init();
         let combo = [_("Ogg Vorbis"), _("Opus"), _("FLAC"), _("MP3"), _("MOV")];
 
         for (let i = 0; i < combo.length; i++)
@@ -834,22 +819,19 @@ const EncoderComboBox = new Lang.Class({
         this.set_sensitive(true);
         activeProfile = Application.application.getPreferences();
         this.set_active(activeProfile);
-        this.connect("changed", Lang.bind(this, this._onComboBoxTextChanged));
-    },
+        this.connect("changed", () => this._onComboBoxTextChanged());
+    }
 
-    _onComboBoxTextChanged: function() {
+    _onComboBoxTextChanged() {
         activeProfile = this.get_active();
         Application.application.setPreferences(activeProfile);
     }
 });
 
-const ChannelsComboBox = new Lang.Class({
-    Name: "ChannelsComboBox",
-    Extends: Gtk.ComboBoxText,
-
+var ChannelsComboBox = GObject.registerClass(class ChannelsComboBox extends Gtk.ComboBoxText {
     // channel setting labels in combobox
-    _init: function() {
-        this.parent();
+    _init() {
+        super._init();
         let combo = [_("Mono"), _("Stereo")];
 
         for (let i = 0; i < combo.length; i++)
@@ -858,27 +840,24 @@ const ChannelsComboBox = new Lang.Class({
         this.set_sensitive(true);
         let chanProfile = Application.application.getChannelsPreferences();
         this.set_active(chanProfile);
-        this.connect("changed", Lang.bind(this, this._onChannelComboBoxTextChanged));
-    },
+        this.connect("changed", () => this._onChannelComboBoxTextChanged());
+    }
 
-    _onChannelComboBoxTextChanged: function() {
+    _onChannelComboBoxTextChanged() {
         let channelProfile = this.get_active();
         Application.application.setChannelsPreferences(channelProfile);
     }
 });
 
-const LoadMoreButton = new Lang.Class({
-    Name: 'LoadMoreButton',
-    Extends: Gtk.Button,
-
-    _init: function() {
-        this.parent();
+const LoadMoreButton = GObject.registerClass(class LoadMoreButton extends Gtk.Button {
+    _init() {
+        super._init();
         this._block = false;
         this.label = _("Load More");
         this.get_style_context().add_class('documents-load-more');
-    },
+    }
 
-    onLoadMore: function() {
+    onLoadMore() {
         view.listBoxLoadMore();
     }
 });
